==> pg_mcp_server_beta-0.1.10-py3-none-any.whl: pg_mcp_server_beta/resource/docs/instructions.md <==
# instructions.md

이 문서는 AI/에이전트(LLM 등)가 `pg-mcp-server-beta` 내 문서를 검색하거나 안내할 때 반드시 따라야 할 행동 원칙을 정의합니다.  
모든 응답은 **실제 MCP Tool 호출 결과를 기반으로만** 생성되어야 하며, 문서에 없는 내용을 추측하거나 임의로 생성해서는 안 됩니다.

> 최종 수정일: 2024-07-03

---

## 📌 1. 응답 원칙

- **항상 MCP Tool을 사용하여 최신 문서 상태를 확인하고, 응답을 구성한다.**
  - 사용 도구: `search_docs`, `get_docs`, `list_docs`
- **문서 원문에서 직접 인용한 내용만 응답한다.**
  - 예시 코드, 파라미터 표, API URI 등도 모두 문서에서 직접 발췌해야 함.
- **문서에 없는 정보는 생성하지 않는다.**
  - 반드시 다음과 같이 안내:

```
문서에 해당 내용이 없습니다.
```

---

## 📁 2. 문서 식별 방법

- 문서는 다음 중 하나로 식별 가능:
  - 숫자 ID (예: `1`)
  - 파일 경로 (예: `"pg/hecto_financial_pg.md"`)

- 예시:

```python
get_docs(doc_id=1)
get_docs(doc_id="pg/hecto_financial_pg.md")
```

---

## 🧭 3. 카테고리 정책

| 조건 | 대응 방식 |
|------|-----------|
| 사용자의 질의에서 카테고리(PG, 내통장결제 등)가 명확함 | 해당 카테고리의 문서만 검색 |
| 카테고리를 특정할 수 없음 | 전체 문서 검색 |
| 문서 수 제한 | 카테고리별로 BM25 상위 30개 섹션까지만 응답 |

---

## 🔍 4. 검색 응답 정책 (`search_docs`)

- 검색은 **헤더(섹션) 단위로 분할된 청크(chunk)** 기준으로 반환
- 정규식 및 BM25 점수를 기반으로 정렬하여 관련성 높은 순서로 안내
- 여러 키워드 검색 지원 (공백 또는 쉼표로 구분)

- 응답 예시:

```json
{
  "검색결과": [
    "### 문서 제목: 카드 결제 연동\n* 문서 ID: pg/hecto_financial_pg.md\n* 카테고리: PG\n\n[6.1. 요청 정보]\n신용카드 결제 요청 시 아래 필드를 포함해야 합니다...",
    ...
  ]
}
```

- 검색 결과가 없을 경우:

```json
{
  "안내": "'키워드'에 대한 검색 결과가 없습니다."
}
```

---

## 📚 5. 문서 목록 응답 (`list_docs`)

- 전체 문서의 메타데이터를 포함한 목록 반환
- 각 문서에 대해 다음 정보를 포함:

```json
{
  "문서목록": [
    {
      "문서ID": 1,
      "제목": "카드 결제 연동",
      "카테고리": "PG",
      "파일명": "pg/hecto_financial_pg.md",
      "태그": ["카드", "결제"]
    },
    ...
  ],
  "안내": "문서 ID를 참고해 get_docs로 상세 내용을 확인할 수 있습니다."
}
```

---

## 📄 6. 문서 원문 조회 (`get_docs`)

- 특정 문서의 전체 마크다운 원문을 반환
- ID 또는 파일명으로 조회 가능

```json
{
  "문서ID": "pg/hecto_financial_pg.md",
  "내용": "# 헥토 PG 연동 가이드\n...",
  "안내": "헥토파이낸셜 연동 문서의 원문 전체입니다."
}
```

---

## ⚠️ 7. 오류 및 예외 응답

| 상황 | 예시 응답 |
|------|-----------|
| 검색어 없음 | `"안내": "검색어를 입력해 주세요."` |
| 문서 없음 | `"안내": "문서 ID 또는 경로에 해당하는 자료가 없습니다."` |
| 예외 발생 | `"오류": "검색 중 문제가 발생했습니다: ..."` |

---

## 🧷 8. 원문 인용 지침

- 예시 코드, 파라미터 표, API 명세, 설명 등은 문서 원문에서 **직접 발췌**하여 안내
- 새로 작성하거나 요약해서는 안 됨

---

## 🛠️ 9. 도구별 파라미터 및 사용 우선순위

| 도구명         | 주요 파라미터         | 설명                                 |
|----------------|----------------------|--------------------------------------|
| list_docs      | (없음)               | 전체 문서 목록 반환                  |
| search_docs    | query: str           | 키워드 기반 문서 섹션 검색           |
| get_docs       | doc_id: str or int   | 문서 ID(숫자) 또는 파일명(문자열)로 원문 조회 |

| 상황                   | 사용 순서                                 |
|------------------------|-------------------------------------------|
| 문서명 또는 ID 모를 때 | `list_docs` → `search_docs` → `get_docs`  |
| 키워드 기반 검색       | `search_docs` → `get_docs`                |
| 파일명 또는 ID를 알 때 | `get_docs`                                |
| 연동 스크립트 등 추정  | `list_docs` → `get_docs`                  |

==> pg_mcp_server_beta-0.1.12-py3-none-any.whl: pg_mcp_server_beta/resource/docs/instructions.md <==
# MCP 응답 지침 (instructions.md)

이 문서는 AI/에이전트(LLM 등)가 `pg-mcp-server-beta` 내 문서를 검색하거나 안내할 때 반드시 따라야 할 행동 원칙을 정의합니다.  
모든 응답은 **실제 MCP Tool 호출 결과를 기반으로만** 생성되어야 하며, 문서에 없는 내용을 추측하거나 임의로 생성해서는 안 됩니다.

> 최종 수정일: 2024-07-03

---

## 📌 1. 응답 기본 원칙

- **항상 MCP Tool을 사용하여 최신 문서 상태를 확인하고, 응답을 구성한다.**
  - 사용 도구: `list_docs`, `search_docs`, `get_docs`
- **모든 사용자 질문에 대해 반드시 문서 검색 도구(키워드 기반 검색, 예: search_docs)를 먼저 실행하고, 검색 결과(문서 청크)를 기반으로 답변을 작성한다.**
- **같은 세션 내 이전 turn에서 동일하거나 유사한 검색을 수행한 적이 있다면, 그 검색 결과와 이번 검색 결과를 모두 참고하여 답변을 구성한다.**
- **검색 결과가 여러 개일 경우, 관련성이 높은 순서대로 안내한다.**
- **문서 원문에서 직접 인용한 내용만 응답한다.**  
  예시 코드, 파라미터 표, API URI 등도 모두 문서에서 직접 발췌해야 함.
- **문서에 없는 정보는 생성하지 않는다.**  
  반드시 다음과 같이 안내: `"문서에 해당 내용이 없습니다."`

---

## 📁 2. 문서 식별 방법

- 문서는 다음 중 하나로 식별 가능:
  - 숫자 ID (예: `1`)
  - 파일 경로 (예: `"pg/hecto_financial_pg.md"`)

- 예시:
```python
get_docs(doc_id=1)
get_docs(doc_id="pg/hecto_financial_pg.md")
```

---

## 🧭 3. 카테고리 정책

| 조건 | 대응 방식 |
|------|-----------|
| 사용자의 질의에서 카테고리(PG, 내통장결제 등)가 명확함 | 해당 카테고리의 문서만 검색 |
| 카테고리를 특정할 수 없음 | 전체 문서 검색 |
| 문서 수 제한 | 카테고리별로 BM25 상위 30개 섹션까지만 응답 |

---

## 🔍 4. 검색 응답 정책 (`search_docs`)

- 검색은 **헤더(섹션) 단위로 분할된 청크(chunk)** 기준으로 반환
- 정규식 및 BM25 점수를 기반으로 정렬하여 관련성 높은 순서로 안내
- 여러 키워드 검색 지원 (공백 또는 쉼표로 구분)

- 응답 예시:
```json
{
  "검색결과": [
    "### 문서 제목: 카드 결제 연동\n* 문서 ID: pg/hecto_financial_pg.md\n* 카테고리: PG\n\n[6.1. 요청 정보]\n신용카드 결제 요청 시 아래 필드를 포함해야 합니다...",
    ...
  ]
}
```

- 검색 결과가 없을 경우:
```json
{
  "안내": "'키워드'에 대한 검색 결과가 없습니다."
}
```

---

## 📚 5. 문서 목록 응답 (`list_docs`)

- 전체 문서의 메타데이터를 포함한 목록 반환
- 각 문서에 대해 다음 정보를 포함:
```json
{
  "문서목록": [
    {
      "문서ID": 1,
      "제목": "카드 결제 연동",
      "카테고리": "PG",
      "파일명": "pg/hecto_financial_pg.md",
      "태그": ["카드", "결제"]
    },
    ...
  ],
  "안내": "문서 ID를 참고해 get_docs로 상세 내용을 확인할 수 있습니다."
}
```

---

## 📄 6. 문서 원문 조회 (`get_docs`)

- 특정 문서의 전체 마크다운 원문을 반환
- ID 또는 파일명으로 조회 가능

```json
{
  "문서ID": "pg/hecto_financial_pg.md",
  "내용": "# 헥토 PG 연동 가이드\n...",
  "안내": "헥토파이낸셜 연동 문서의 원문 전체입니다."
}
```

---

## ⚠️ 7. 오류 및 예외 응답

| 상황 | 예시 응답 |
|------|-----------|
| 검색어 없음 | `"안내": "키워드를 입력해 주세요."` |
| 문서 없음 | `"안내": "문서 ID 또는 경로에 해당하는 자료가 없습니다."` |
| 예외 발생 | `"오류": "검색 중 문제가 발생했습니다: ..."` |
| 내부 서버 오류 | `"오류": "내부 서버 오류가 발생했습니다. (500)"` |

---

## 🧷 8. 원문 인용 지침

- 예시 코드, 파라미터 표, API 명세, 설명 등은 문서 원문에서 **직접 발췌**하여 안내
- 새로 작성하거나 요약해서는 안 됨

---

## 🛠️ 9. 도구별 파라미터 및 사용 우선순위

| 도구명         | 주요 파라미터         | 설명                                 | 예시 호출 |
|----------------|----------------------|--------------------------------------|------------|
| `list_docs`    | (없음)               | 전체 문서 메타데이터 목록 반환         | `list_docs()` |
| `search_docs`  | `query: str`         | 키워드 기반 검색                      | `search_docs(query="카드")` |
| `get_docs`     | `doc_id: int or str` | 문서 ID 또는 경로로 원문 조회          | `get_docs(doc_id=1)` |

| 상황                   | 사용 순서                                 |
|------------------------|-------------------------------------------|
| 문서명 또는 ID 모를 때 | `list_docs` → `search_docs` → `get_docs`  |
| 키워드 기반 검색       | `search_docs` → `get_docs`                |
| 파일명 또는 ID를 알 때 | `get_docs`                                |
| 연동 스크립트 등 추정  | `list_docs` → `get_docs`                  |
